#' Norwegian characters in unicode
#' @export nor_char
nor_char <- new.env()
nor_char$AA <- "\u00C5"
nor_char$aa <- "\u00E5"
nor_char$OE <- "\u00D8"
nor_char$oe <- "\u00F8"
nor_char$AE <- "\u00C6"
nor_char$ae <- "\u00E6"
